@@ -420,7 +420,8 @@ sub clone {
   $new->[NAMES] = [@{$$self->[NAMES]}];
   $new->[VALUES] = [@{$$self->[VALUES]}];
   $new->[MVOFF] = [@{$$self->[MVOFF]}] if defined $$self->[MVOFF];
-  $new->[INDEX] = {%{$$self->[INDEX]}} if defined $$self->[INDEX];
+  $new->[INDEX] = {map {$_ => [@{$$self->[INDEX]{$_}}]}
+		   keys %{$$self->[INDEX]}} if defined $$self->[INDEX];
 
   {our $_total_newly_cloned;		$_total_newly_cloned++}
   bless \ $new, ref $self;
