@@ -53,6 +53,22 @@ sub attach {
     .(shift)." must override the 'attach' method"
 }
 
+=item $yes_or_no = $index-E<gt>searchable( $key )
+
+Return true or false to reflect if the index can search for the requested
+key.  Indexes may be able to search for keys that are not present in
+entries returned from those indexes.
+
+See the L<"Search Keys" section|WARC::Collection/"Search Keys"> of the
+C<WARC::Collection> page for details on the implemented search keys.
+
+=cut
+
+sub searchable {
+  die __PACKAGE__." is an abstract base class and "
+    .(ref shift)." must override the 'searchable' method"
+}
+
 =item $record = $index-E<gt>search( ... )
 
 =item @records = $index-E<gt>search( ... )
@@ -60,6 +76,9 @@ sub attach {
 Search an index for records matching parameters.  The C<WARC::Collection>
 class uses this method to search each index in a collection.
 
+If the none of the requested search keys are searchable, returns an
+undefined value in scalar context and the empty list in list context.
+
 The details of the parameters for this method are documented in the
 L<"Search Keys" section|WARC::Collection/"Search Keys"> of the
 C<WARC::Collection> page.
@@ -99,6 +118,28 @@ sub build {
 
 =back
 
+=head2 Optional Methods
+
+Some index systems may also provide these methods:
+
+=over
+
+=item $entry = $index-E<gt>first_entry
+
+An index that has a sequential ordering may provide this method to obtain
+the first entry in the index.  Indexes that do not have a meaningful
+sequence amongst their entries do not provide this method.
+
+=item $entry = $index-E<gt>entry_at( $position )
+
+An index that has a sequential ordering may provide this method to obtain
+an entry at a specified position in the index.  The exact format of the
+position parameter is not specified in general, but should be a value
+previously obtained from the C<entry_position> method on an entry from the
+same index.  Valid positions may be sparse.
+
+=back
+
 =head2 Index system registration
 
 The C<WARC::Index> package also provides a registry of loaded index
@@ -169,7 +210,7 @@ Jacob Bachmeyer, E<lt>jcb@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<WARC>
+L<WARC>, L<WARC::Index::Entry>
 
 =head1 COPYRIGHT AND LICENSE
 
